TextPixel class abstract

Inheritance
Implementers

Constructors

TextPixel(String lnString, {PixelInlineAlign textAlign = PixelInlineAlign.left, ContextAccessor? ctxAccessor, Alignment? alignment = Alignment.topLeft, double? lineHeight, double? pixelSize, Anchor anchor = Anchor.topLeft, Color? bgColor, Rect? paintRect, Size? scaledPixelSize, Color? color, Anchor paintRectAnchor = Anchor.topLeft})

Properties

anchor Anchor
getter/setter pairinherited
bgColor Color?
finalinherited
color Color?
finalinherited
containerAnchor Anchor
no setterinherited
containerRect Rect
no setterinherited
ctxAccessor ↔ ContextAccessor?
getter/setter pairinherited
ctxSize Size
no setterinherited
drawBlank bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
inlineAlign PixelInlineAlign
getter/setter pairinherited
isPixelScaled bool
no setterinherited
lineHeight double
no setter
lineNum int
no setter
linePixelNum int
no setter
lnString String
final
offsetX double
no setterinherited
offsetY double
no setterinherited
paintRect Rect?
finalinherited
paintRectAnchor Anchor
getter/setter pairinherited
pixel Pixel
no setteroverride
pixelSize double
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaledPixelSize Size
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
size Size
no setterinherited
textPixelInfo → (int, Pixel)
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
asBackground({Widget? child}) CustomPaint
inherited
asForeground({Widget? child}) CustomPaint
inherited
delegatePaint(Canvas canvas, Size size) → void
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
givePainterCall(ContextAccessor? ctxAccessor) → PainterCall?
该方法使得绘图方法只依赖一次 ctx 并缓存以来的计算数据,比如大小位置信息等。
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
inherited
paintContext(ContextAccessor? ctxAccessor, Canvas ctxCanvas, Size ctxSize) → void
该方法使得绘图方法次次依赖实时的 ctx 数据,可能造成性能影响
inherited
paintPixel(String instructStr, int xIndex, int yIndex, Canvas ctxCanvas, Rect paintRect) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
toSizedWidget([Widget? child]) SizedBox
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited