Pixel class

Constructors

Pixel({required ({int height, int width}) size, required List<String> data})
const
Pixel.empty()
factory

Properties

data List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size → ({int height, int width})
final

Methods

lineAt(int xAt, int yLine) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizedAt(int xAt, int ySized) String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited