PixelCombineMode enum

/ 像素连接种类

Inheritance
Available extensions

Values

LR → const PixelCombineMode
TB → const PixelCombineMode
RL → const PixelCombineMode
BT → const PixelCombineMode
LR_OFFSET → const PixelCombineMode
TB_OFFSET → const PixelCombineMode
RL_OFFSET → const PixelCombineMode
BT_OFFSET → const PixelCombineMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PixelCombineMode>
A constant List of the values in this enum, in order of their declaration.