PixelImage class

Constructors

PixelImage(String data)
const

Properties

data String
final
hashCode int
The hash code for this object.
no setterinherited
pixel Pixel
no setter
pure List<String>
去掉占位行信息
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pixelRepeat([int times = 1]) Pixel
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited