Anchor class
copied from flame avoid include the whole flame files.
- Annotations
Constructors
- Anchor(double x, double y)
-
const
- Anchor.valueOf(String name)
-
This should only be used for de-serialization purposes.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
Returns a string representation of this Anchor.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → double
-
The relative x position with respect to the object's width;
0 means totally to the left (beginning) and 1 means totally to the
right (end).
final
- y → double
-
The relative y position with respect to the object's height;
0 means totally to the top (beginning) and 1 means totally to the
bottom (end).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a string representation of this Anchor.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- bottomCenter → const Anchor
- bottomLeft → const Anchor
- bottomRight → const Anchor
- center → const Anchor
- centerLeft → const Anchor
- centerRight → const Anchor
- topCenter → const Anchor
- topLeft → const Anchor
- topRight → const Anchor